@@ -1,7 +1,7 @@
 /*
- * $Id: radexample.c,v 1.2 1996/01/14 02:40:45 lf Exp $
+ * $Id: radexample.c,v 1.3 1996/03/18 23:20:26 lf Exp $
  *
- * Copyright (C) 1995 Lars Fenneberg
+ * Copyright (C) 1995,1996 Lars Fenneberg
  *
  * See the file COPYRIGHT for the respective terms and conditions. 
  * If the file is missing contact me at in5y050@public.uni-hamburg.de 
@@ -11,10 +11,10 @@
 
 
 static char	rcsid[] =
-		"$Id: radexample.c,v 1.2 1996/01/14 02:40:45 lf Exp $";
+		"$Id: radexample.c,v 1.3 1996/03/18 23:20:26 lf Exp $";
 
 static char	copyright_1[] =
-		"$Copyright: (C) 1995 Lars Fenneberg $";
+		"$Copyright: (C) 1995,1996 Lars Fenneberg $";
 
 #include	<sys/types.h>
 
@@ -22,6 +22,7 @@ static char	copyright_1[] =
 #include	<string.h>
 
 #include	"../src/radius.h"
+#include	"../src/pathnames.h"
 
 int
 main (int argc, char **argv)
@@ -33,7 +34,7 @@ main (int argc, char **argv)
 	UINT4		service;
 	char 		msg[4096], username_realm[256];
 
-	if (rc_read_config(RADIUSCLIENT_CONF) != 0)
+	if (rc_read_config(_PATH_ETC_RADIUSCLIENT_CONF) != 0)
 		exit(ERROR_RC);
 	
 	if (rc_read_dictionary(conf_dictionary) != 0)
