@@ -1,5 +1,5 @@
 /*
- * $Id: log.c,v 1.6 1996/01/05 02:29:56 lf Exp $
+ * $Id: log.c,v 1.7 1996/03/18 23:20:19 lf Exp $
  *
  * Copyright (C) 1995 Lars Fenneberg
  *
@@ -34,7 +34,7 @@ void rc_log(int prio, char *format, ...)
         vsprintf(buff, format, ap);
         va_end(ap);
 
-	fprintf(stderr,"%s\n", buff);
+	fprintf(stderr,"%s\r\n", buff);
 	
 	/* stderr usually is unbuffered, but just to make sure */
 	fflush(stderr);
