@@ -1,7 +1,7 @@
 /*
- * $Id: radius.h,v 1.8 1996/03/15 13:53:04 lf Exp $
+ * $Id: radius.h,v 1.9 1996/03/18 23:20:19 lf Exp $
  *
- * Copyright (C) 1995, 1996 Lars Fenneberg
+ * Copyright (C) 1995,1996 Lars Fenneberg
  *
  * Copyright 1992 Livingston Enterprises, Inc.
  *
@@ -31,9 +31,8 @@ typedef long 	      INT4;
 #define AUTH_ID_LEN		64
 #define AUTH_STRING_LEN		128	/* maximum of 253 */
 
-#define FILE_PFX_LEN		16
-#define FILTER_LEN		16
 #define NAME_LENGTH		32
+#define	GETSTR_LENGTH		32	/* must be bigger than AUTH_PASS_LEN */
 
 /* codes for radius_buildreq, radius_getport, etc. */
 #define AUTH			0
@@ -230,13 +229,6 @@ typedef struct pw_auth_hdr
 #define PW_ISDN_SYNC_V120	3
 #define PW_ISDN_SYNC_V110	4
 
-/* Default Configuration File Name */
-/* normally set in Makefile */
-
-#ifndef RADIUSCLIENT_CONF
-#define RADIUSCLIENT_CONF	"/etc/radiusclient.conf"
-#endif
-
 /* Server data structures */
 
 typedef struct dict_attr
@@ -265,34 +257,7 @@ typedef struct value_pair
 	struct value_pair *next;
 } VALUE_PAIR;
 
-typedef struct auth_req
-{
-	UINT4             ipaddr;	    /* IP address of requestor */
-	u_short           udp_port;         /* UDP reply socket of requestor */
-	u_char            id;               /* Original request seq. number */
-	u_char            code;             /* Type of RADIUS packet */
-	u_char            vector[AUTH_VECTOR_LEN];
-	u_char            secret[MAX_SECRET_LENGTH + 1];
-	u_char            ttl;              /* Global queue time-to-live secs */
-	u_char            timer;            /* General utility timer */
-	u_char            reply_id;         /* RADIUS-to-RADIUS seq. number */
-	u_char            retry_cnt;        /* Counter for duplicate requests */
-	u_char            file_pfx[FILE_PFX_LEN + 1];
-	u_char            realm_filter[FILTER_LEN + 1];
-	u_char            state;            /* State of current request */
-	int               result;           /* Result of previous action */
-	int               cur_count;        /* Original number request pairs */
-	struct aatv      *fsm_aatv;         /* Pointer to current FSM action */
-	struct aatv      *direct_aatv;      /* Pointer to actual action */
-	struct event_ent *event_q;          /* Pointer to active event queue */
-	struct auth_req  *next;             /* Global request queue link */
-	VALUE_PAIR       *request;          /* Original client a/v pairs */
-	VALUE_PAIR       *cur_request;      /* Represents current a/v pairs */
-	VALUE_PAIR       *user_check;       /* List of users file check items */
-	VALUE_PAIR       *user_reply;       /* List of users file reply items */
-} AUTH_REQ;
-
-
+/* don't change this, as it has to be the same as in the Merit radiusd code */
 #define MGMT_POLL_SECRET	"Hardlyasecret"
 
 /* 	Define return codes from "SendServer" utility */
@@ -415,6 +380,7 @@ extern int conf_login_tries;
 extern char *conf_seqfile;
 extern int conf_login_timeout;
 extern char *conf_mapfile;
+extern char *conf_nologin;
 
 extern int conf_numauth;	/* number of authentication servers */
 extern int conf_numacct;	/* number of accounting servers */
