@@ -1,7 +1,7 @@
 /*
- * $Id: radlogin.c,v 1.12 1996/03/15 13:53:04 lf Exp $
+ * $Id: radlogin.c,v 1.13 1996/03/18 23:20:19 lf Exp $
  *
- * Copyright (C) 1995 Lars Fenneberg
+ * Copyright (C) 1995,1996 Lars Fenneberg
  *
  * See the file COPYRIGHT for the respective terms and conditions. 
  * If the file is missing contact me at in5y050@public.uni-hamburg.de 
@@ -10,10 +10,10 @@
  */
 
 static char	rcsid[] =
-		"$Id: radlogin.c,v 1.12 1996/03/15 13:53:04 lf Exp $";
+		"$Id: radlogin.c,v 1.13 1996/03/18 23:20:19 lf Exp $";
 
 static char	copyright_1[] =
-		"$Copyright: (C) 1995 Lars Fenneberg $";
+		"$Copyright: (C) 1995,1996 Lars Fenneberg $";
 
 static char	copyright_2[] =
 		"$Parts: (C) 1992 Livingston Enterprises, Inc. $";
@@ -37,19 +37,22 @@ University of Michigan and Merit Network, Inc. All Rights Reserved $";
 #include	<stdlib.h>
 #include	<ctype.h>
 #include	<syslog.h>
+#include	<limits.h>
 
 #ifdef SHADOW_PASSWORD
 #include <shadow.h>
 #endif
 
 #include	"radius.h"
+#include	"messages.h"
+#include	"pathnames.h"
 
 static char *pname = NULL;
 static struct env *env = NULL;
 
 void alarm_handler(int sn)
 {
-	rc_log(LOG_ERR,"\r\nlogin timed out after %d seconds. Bye.", conf_login_timeout);
+	rc_log(LOG_ERR, SC_TIMEOUT, conf_login_timeout);
 	sleep(1);
 	exit(1);	
 }
@@ -109,11 +112,19 @@ int auth_radius(UINT4 client_port, char *username, char *passwd)
 
 	rc_avpair_add(&send, PW_SERVICE_TYPE, &service);
 
+	/* Fill in Framed-Protocol, if neccessary */
+	
 	if (ftype != 0)
 	{
 		rc_avpair_add(&send, PW_FRAMED_PROTOCOL, &ftype);	
 	} 
-	 
+
+	/* Fill in Framed-Compression, if neccessary */
+
+	if (ctype != 0)
+	{
+		rc_avpair_add(&send, PW_FRAMED_COMPRESSION, &ctype);	
+	} 
 	 
 	/*
 	 * Fill in User-Name
@@ -165,20 +176,11 @@ int auth_radius(UINT4 client_port, char *username, char *passwd)
 			vp = vp->next;
 		}
 
-#ifdef SCP
-		/* the RADIUS server doesnt distinguish between compressed
-		   and non-compressed slip. so we explicitly set 
-		   Framed-Compression here	  -lf, 03/15/96 */
-
-		if ((ftype = PW_SLIP) && (ctype == PW_VAN_JACOBSON_TCP_IP))
-			rc_add_env(env, "RADIUS_FRAMED_COMPRESSION", "Van-Jacobson-TCP-IP");
-
-#endif
-		rc_log(LOG_NOTICE, "\"%s\" RADIUS authentication OK", username);
+		rc_log(LOG_NOTICE, SC_RADIUS_OK, username);
 	}
 	else
 	{
-		rc_log(LOG_NOTICE, "\"%s\" RADIUS authentication failed (RC=%i)", username, result);
+		rc_log(LOG_NOTICE, SC_RADIUS_FAILED, username, result);
 	}
 	
 	return result;
@@ -194,7 +196,7 @@ int auth_local(char *username, char *passwd)
 
 	if ((pw = getpwnam(username)) == NULL) {
 		endpwent();
-		rc_log(LOG_NOTICE, "\"%s\" local authentication failed", username);
+		rc_log(LOG_NOTICE, SC_LOCAL_FAILED, username);
 		return BADRESP_RC;
 	}
 	endpwent();
@@ -202,7 +204,7 @@ int auth_local(char *username, char *passwd)
 #ifdef SHADOW_PASSWORD
         if((spw = getspnam(pw->pw_name)) == NULL) {
 		endspent();
-		rc_log (LOG_NOTICE, "\"%s\" local authentication failed", username);
+		rc_log (LOG_NOTICE, SC_LOCAL_FAILED, username);
 		return BADRESP_RC;
         }
         else 
@@ -215,11 +217,11 @@ int auth_local(char *username, char *passwd)
 	xpasswd = crypt(passwd, pw->pw_passwd);
 	
 	if (*pw->pw_passwd == '\0' || strcmp(xpasswd, pw->pw_passwd)) {
-		rc_log(LOG_NOTICE, "\"%s\" local authentication failed", username);
+		rc_log(LOG_NOTICE, SC_LOCAL_FAILED, username);
 		return BADRESP_RC;		
 	}
 
-	rc_log(LOG_NOTICE, "\"%s\" local authentication OK", username);
+	rc_log(LOG_NOTICE, SC_LOCAL_OK, username);
 	return OK_RC;
 }
 
@@ -252,6 +254,40 @@ radius_login(char *username)
 	exit(ERROR_RC);
 }
 
+int
+login_allowed(char *tty)
+{
+	FILE *fp;
+#ifdef PATH_MAX
+	char fname[PATH_MAX];
+#else
+	char fname[1024];
+#endif
+	int c;
+
+	strcpy(fname, conf_nologin);
+	if (access(fname, F_OK) < 0) {
+		sprintf(fname, "%s.%s", conf_nologin, tty);
+		if (access(fname, F_OK) < 0)
+			return 1;
+	}
+
+	if ((fp = fopen(fname, "r")) != NULL)
+	{
+		while ((c = fgetc(fp)) != EOF)
+		{
+			if (c == '\n')
+				fputc(c, stdout);
+			fputc(c, stdout);
+		}
+		fflush(stdout);
+		fclose(fp);
+	} else {
+		printf(SC_NOLOGIN);
+	}
+	return (0);		
+}
+
 void usage(void)
 {
 	fprintf(stderr,"Usage: %s [-Vh] [-i <client_port>]\n", pname);
@@ -275,13 +311,15 @@ main (int argc, char **argv)
 	char            passwd[AUTH_PASS_LEN + 1];
 	int 		tries, remaining, c;
 	UINT4		client_port;
+	char		*tty, *ttyn;
+	void 		(*login_func)(char *);	
 
         extern char *optarg;
         extern int optind;
 
 	pname = (pname = strrchr(argv[0],'/'))?pname+1:argv[0];
 	
-	if (rc_read_config(RADIUSCLIENT_CONF) != 0)
+	if (rc_read_config(_PATH_ETC_RADIUSCLIENT_CONF) != 0)
 		exit(ERROR_RC);
 	
 	if (rc_read_dictionary(conf_dictionary) != 0)
@@ -290,7 +328,13 @@ main (int argc, char **argv)
 	if (rc_read_mapfile(conf_mapfile) != 0)
 		exit (ERROR_RC);
 
-	client_port = rc_map2id(ttyname(1));
+	ttyn = ttyname(0);
+	if ((tty = strrchr(ttyn, '/')) == NULL)
+		tty = ttyn;
+	else
+		tty += 1;
+
+	client_port = rc_map2id(ttyn);
 
 	while ((c = getopt(argc,argv,"i:hV")) > 0)
 	{
@@ -340,11 +384,13 @@ main (int argc, char **argv)
 	 alarm(remaining);
 
 	 while (!*username) {
-	 		strncpy(username, rc_getstr ("login: ",1), sizeof(username));
+	 		strncpy(username, rc_getstr (SC_LOGIN, 1), sizeof(username));
 	 }
-	 strncpy (passwd, rc_getstr("Password: ",0), sizeof (passwd));		
+	 strncpy (passwd, rc_getstr(SC_PASSWORD, 0), sizeof (passwd));		
 
 	 remaining = alarm(0);
+	 
+	 login_func = NULL;
 
  	 if (conf_auth_type & AUTH_LOCAL_FST)
  	 {
@@ -353,13 +399,11 @@ main (int argc, char **argv)
  	 		if (conf_auth_type & AUTH_RADIUS_SND) {
  	 			result = auth_radius(client_port, username, passwd);
  	 			if (result == OK_RC) {
-					memset(passwd, '\0', sizeof(passwd));
- 	 				radius_login(username); /* never returns */
+ 					login_func = radius_login;
  	 			}
  	 		}
  	 	} else {
-			memset(passwd, '\0', sizeof(passwd));
- 	 		local_login(username); /* never returns */
+			login_func = local_login;
  	 	}
  	 }
  	 else
@@ -370,16 +414,24 @@ main (int argc, char **argv)
  	 			result = auth_local(username, passwd);
  	 			if (result == OK_RC)
  	 			{
- 	 				memset(passwd, '\0', sizeof(passwd));
- 	 				local_login(username); /* never returns */
+					login_func = local_login;
  	 			}
  	 		}
  	 	} else {
- 	 		memset(passwd, '\0', sizeof(passwd));
- 	 		radius_login(username); /* never returns */
+			login_func = radius_login;
  	 	}
  	 }
 
+	 memset(passwd, '\0', sizeof(passwd));
+
+	 if (login_func != NULL)
+	 	if (login_allowed(tty)) {
+	 		(*login_func)(username);
+		} else {
+			sleep(1);
+			exit (ERROR_RC);
+		}
+
 	 *username = '\0';
 	 
 	 if ((++tries) <= conf_login_tries) {
@@ -390,7 +442,7 @@ main (int argc, char **argv)
 
 	}
 
-	rc_log(LOG_INFO, "maximum login tries exceeded. Go away!");
+	rc_log(LOG_INFO, SC_EXCEEDED);
 	sleep(1);
 	
 	exit (ERROR_RC);
