@@ -1,7 +1,7 @@
 /*
- * $Id: sendserver.c,v 1.10 1996/03/15 13:53:04 lf Exp $
+ * $Id: sendserver.c,v 1.11 1996/03/18 23:20:19 lf Exp $
  *
- * Copyright (C) 1995 Lars Fenneberg
+ * Copyright (C) 1995,1996 Lars Fenneberg
  *
  * Copyright 1992 Livingston Enterprises, Inc.
  *
@@ -28,8 +28,10 @@
 #include	<string.h>
 #include	<stdlib.h>
 #include	<syslog.h>
+#include	<fcntl.h>
 
 #include	"radius.h"
+#include	"pathnames.h"
 
 void md5_calc (unsigned char *, unsigned char *, unsigned int);
 static void rc_random_vector (unsigned char *);
@@ -437,7 +439,23 @@ static void rc_random_vector (unsigned char *vector)
 {
 	int             randno;
 	int             i;
+#if defined(linux) && defined(DEV_URANDOM)
+	int		fd;
 
+/* well, I added this to increase the security for user passwords.
+   we use /dev/urandom here, as /dev/random might block and we don't
+   need that much randomness. BTW, great idea, Ted!     -lf, 03/18/95	*/
+	
+	if ((fd = open(_PATH_DEV_URANDOM, O_RDONLY)) >= 0)
+	{
+		/* one read should suffice, but to be sure... */
+		i = AUTH_VECTOR_LEN;
+		while (i > 0)
+			i -= read(fd, (char *)vector, i);
+	
+		return;			
+	} /* else fall through */
+#endif
 	srand (time (0) + getppid() + getpid()); /* random enough :) */
 	for (i = 0; i < AUTH_VECTOR_LEN;)
 	{
@@ -446,5 +464,6 @@ static void rc_random_vector (unsigned char *vector)
 		vector += sizeof (int);
 		i += sizeof (int);
 	}
+
 	return;
 } 
